@@ -41,10 +41,20 @@ pub enum DeserializeErrorKind {
 	Custom(String),
 	#[error("{0}")]
 	Invalid(String),
+	#[error("Expected integer, got {0:?}")]
+	IntFraction(String),
+	#[error("{0:?} is too big")]
+	IntOverflow(String),
+	#[error("Expected unsigned integer, got -{0}")]
+	IntSigned(u128),
+	#[error("Unexpected characters after number {0:?}")]
+	NumTrailing(String),
+	#[error("e exponents only supported in base 10")]
+	NumExpBase,
+	#[error("Could not parse exponent as integer: {0}")]
+	NumExpInvalid(#[source] std::num::ParseIntError),
 	#[error(transparent)]
 	Io(#[from] std::io::Error),
-	#[error(transparent)]
-	ParseInt(#[from] std::num::ParseIntError),
 	#[error("{0} is not supported.")]
 	Unimplemented(&'static str),
 	#[error("Invalid UTF-8")]
