@@ -16,9 +16,9 @@ impl<'a, R: buffered_reader::BufferedReader<()>> KeyDeserializer<'a, R> {
 		(unsafe { crate::from_utf8_unchecked(b) }, location)
 	}
 
-	fn take_sint<T: std::convert::TryFrom<u128> + std::ops::Neg>(self) -> Result<T, crate::DeserializeError>
+	fn take_sint<T: std::convert::TryFrom<i128> + std::ops::Neg>(self) -> Result<T, crate::DeserializeError>
 	where
-		<T as std::convert::TryFrom<u128>>::Error: std::fmt::Debug,
+		<T as std::convert::TryFrom<i128>>::Error: std::fmt::Debug,
 		<T as std::ops::Neg>::Output: std::convert::Into<T>,
 	{
 		let (s, location) = self.take_key();
@@ -32,6 +32,11 @@ impl<'a, R: buffered_reader::BufferedReader<()>> KeyDeserializer<'a, R> {
 		let (s, location) = self.take_key();
 		crate::parse_num(s, location)?.to_uint(s).map_err(|e| e.at(location))
 	}
+
+	fn take_float(self) -> Result<f64, crate::DeserializeError> {
+		let (s, location) = self.take_key();
+		crate::parse_num(s, location).map(|n| n.to_f64())
+	}
 }
 
 impl<'d, 'a, R: buffered_reader::BufferedReader<()>> serde::de::Deserializer<'d> for KeyDeserializer<'a, R> {
@@ -94,12 +99,12 @@ impl<'d, 'a, R: buffered_reader::BufferedReader<()>> serde::de::Deserializer<'d>
 		visitor.visit_u128(self.take_uint()?)
 	}
 
-	fn deserialize_f32<V: serde::de::Visitor<'d>>(self, _visitor: V) -> Result<V::Value, crate::DeserializeError> {
-		Err(crate::DeserializeErrorKind::Unimplemented("deserialize_f32").at(self.root.location))
+	fn deserialize_f32<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, crate::DeserializeError> {
+		visitor.visit_f32(self.take_float()? as f32)
 	}
 
-	fn deserialize_f64<V: serde::de::Visitor<'d>>(self, _visitor: V) -> Result<V::Value, crate::DeserializeError> {
-		Err(crate::DeserializeErrorKind::Unimplemented("deserialize_f64").at(self.root.location))
+	fn deserialize_f64<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, crate::DeserializeError> {
+		visitor.visit_f64(self.take_float()?)
 	}
 
 	fn deserialize_char<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, crate::DeserializeError> {
