@@ -9,10 +9,11 @@ impl<'d, 'a, T: buffered_reader::BufferedReader<()>> serde::de::MapAccess<'d> fo
 	fn next_key_seed<K: serde::de::DeserializeSeed<'d>>(&mut self, seed: K) -> Result<Option<K::Value>, crate::DeserializeError> {
 		let b = self.root.input.read_to(b':')?;
 
-		let mut s = std::str::from_utf8(b)?;
+		let mut s = crate::from_utf8(b, self.root.location)?;
 		let mut indent_len = 0;
 		while let Some(c) = s[indent_len..].chars().next() {
 			if c == '\n' {
+				self.root.location.add_lines(1);
 				let len = s.len() - 1;
 				self.root.input.consume(indent_len + 1);
 				let b = &self.root.input.buffer()[..len];
@@ -43,19 +44,28 @@ impl<'d, 'a, T: buffered_reader::BufferedReader<()>> serde::de::MapAccess<'d> fo
 				root.push_str(&indent[root.len()..]);
 				self.first = false;
 			} else {
-				return Err(crate::DeserializeError::Invalid(format!("Unmatched indent, was {:?} now {:?}", self.root.indent, indent)))
+				return Err(
+					crate::DeserializeErrorKind::Invalid(
+						format!("Unmatched indent, was {:?} now {:?}",
+							self.root.indent, indent))
+						.at(self.root.location))
 			}
 		} else {
 			self.root.indent = Some(indent.into());
 			self.first = false;
 		}
 
+		self.root.location.add_columns(indent_len);
+
 		if key.is_empty() {
 			// EOF
 			return Ok(None)
 		}
 		if !key.ends_with(':') {
-			return Err(crate::DeserializeError::Invalid("Unexpected EOF, expecting :".into()))
+			return Err(
+				crate::DeserializeErrorKind::Invalid(
+					"Unexpected EOF, expecting :".into())
+					.at(self.root.location))
 		}
 		let key = &key[..key.len()-1];
 		let key_len = key.len();
